@@ -67,7 +67,7 @@ class Cleanup(base.Base):
         molecule.yml.
     """
 
-    def execute(self):
+    def execute(self, action_args=None):
         """
         Execute the actions necessary to cleanup the instances and returns \
         None.
