@@ -64,7 +64,7 @@ class Dependency(base.Base):
         molecule.yml.
     """
 
-    def execute(self):
+    def execute(self, action_args=None):
         """
         Execute the actions necessary to perform a `molecule dependency` and \
         returns None.
