@@ -87,7 +87,7 @@ class Destroy(base.Base):
        Run in parallelizable mode.
     """
 
-    def execute(self):
+    def execute(self, action_args=None):
         """
         Execute the actions necessary to perform a `molecule destroy` and \
         returns None.
