@@ -68,7 +68,7 @@ class Idempotence(base.Base):
         molecule.yml.
     """
 
-    def execute(self):
+    def execute(self, action_args=None):
         """
         Execute the actions necessary to perform a `molecule idempotence` and \
         returns None.
