@@ -74,7 +74,7 @@ class Lint(base.Base):
     def env(self):
         return util.merge_dicts(self._config.env, os.environ)
 
-    def execute(self):
+    def execute(self, action_args=None):
         """
         Execute the actions necessary to perform a `molecule lint` and \
         returns None.
@@ -97,7 +97,7 @@ class Lint(base.Base):
         result = util.run_command(cmd, env=self.env, echo=True)
         if result.returncode != 0:
             util.sysexit_with_message(
-                "Lint failed with error code %s" % result.returncode
+                f"Lint failed with error code {result.returncode}"
             )
 
 
@@ -107,9 +107,7 @@ class Lint(base.Base):
     "--scenario-name",
     "-s",
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help="Name of the scenario to target. ({})".format(
-        base.MOLECULE_DEFAULT_SCENARIO_NAME
-    ),
+    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
 def lint(ctx, scenario_name):  # pragma: no cover
     """Lint the role (dependency, lint)."""
