@@ -82,7 +82,7 @@ class Base(object):
         util.sysexit(exception.returncode)
 
     @abc.abstractmethod
-    def execute(self):  # pragma: no cover
+    def execute(self, action_args=None):  # pragma: no cover
         """
         Execute ``cmd`` and returns None.
 
