@@ -24,8 +24,6 @@ import os
 from abc import ABCMeta, abstractmethod
 from typing import Dict
 
-import pkg_resources
-
 import molecule
 from molecule.status import Status
 
@@ -45,7 +43,7 @@ class Driver(object):
         self._config = config
         self._path = os.path.abspath(os.path.dirname(inspect.getfile(self.__class__)))
         self.module = self.__module__.split(".", maxsplit=1)[0]
-        self.version = pkg_resources.get_distribution(self.module).version
+        self.version = molecule.version(self.module)
 
     @property
     @abstractmethod
