@@ -17,7 +17,7 @@
 #  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
-"""Schema v2 Validation Module."""
+"""Schema v3 Validation Module."""
 
 import collections
 import functools
@@ -328,7 +328,7 @@ class Validator(cerberus.Validator):
             data = (doc[field] for doc in self.root_document[root_key])
             for key, count in collections.Counter(data).items():
                 if count > 1:
-                    msg = "'{}' is not unique".format(key)
+                    msg = f"'{key}' is not unique"
                     self._error(field, msg)
 
     def _validate_disallowed(self, disallowed, field, value):
