@@ -57,6 +57,14 @@ def driver_name(request: FixtureRequest) -> Optional[str]:
         return None
 
 
+@pytest.fixture
+def platform_name(request):
+    try:
+        return request.param
+    except AttributeError:
+        return None
+
+
 @pytest.mark.extensive
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
@@ -108,13 +116,13 @@ def test_command_converge(scenario_to_test, with_scenario, scenario_name):
 )
 @pytest.mark.serial
 def test_command_create(scenario_to_test, with_scenario, scenario_name, tmp_path):
-    os.environ["ANSIBLE_ROLES_PATH"] = str(tmp_path)
     cmd = ["molecule", "create", "--scenario-name", scenario_name]
     assert run_command(cmd, env=os.environ).returncode == 0
 
-    # Validate that ansible-compat created a symlink in the roles path
-    role_path = tmp_path / "molecule.delegated_test"
-    assert role_path.is_symlink()
+    # TODO(ssbarnea): Include these additional checks
+    # role_list = run_command(["ansible-galaxy", "role", "list"], env=os.environ)
+    # assert role_list.returncode == 0, role_list
+    # assert "- molecule.delegated_test, (unknown version)" in role_list.stdout
 
 
 @pytest.mark.parametrize(
@@ -125,18 +133,12 @@ def test_command_create(scenario_to_test, with_scenario, scenario_name, tmp_path
             "delegated",
             "shell",
             id="shell",
-            marks=pytest.mark.xfail(
-                reason="https://github.com/ansible-community/molecule/issues/3171"
-            ),
         ),
         pytest.param(
             "dependency",
             "delegated",
             "ansible-galaxy",
             id="galaxy",
-            marks=pytest.mark.xfail(
-                reason="https://github.com/ansible-community/molecule/issues/3171"
-            ),
         ),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
@@ -178,15 +180,13 @@ def test_command_idempotence(scenario_to_test, with_scenario, scenario_name):
 
 @pytest.mark.serial
 @pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
-@pytest.mark.xfail(reason="https://github.com/ansible-community/molecule/issues/3171")
-def test_command_init_role(temp_dir, driver_name, skip_test):
+def test_command_init_role(temp_dir, driver_name):
     init_role(temp_dir, driver_name)
 
 
 @pytest.mark.serial
 @pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
-@pytest.mark.xfail(reason="https://github.com/ansible-community/molecule/issues/3171")
-def test_command_init_scenario(temp_dir, driver_name, skip_test):
+def test_command_init_scenario(temp_dir, driver_name):
     init_scenario(temp_dir, driver_name)
 
 
@@ -293,6 +293,60 @@ def test_command_test(scenario_to_test, with_scenario, scenario_name, driver_nam
     run_test(driver_name, scenario_name)
 
 
+def run_test_with_platform_name(
+    driver_name, platform_name, scenario_name="default", parallel=False
+):
+    cmd = [
+        "molecule",
+        "-vvv",
+        "--debug",
+        "test",
+        "--scenario-name",
+        scenario_name,
+        "--platform-name",
+        platform_name,
+    ]
+    if driver_name != "delegated":
+        if scenario_name is None:
+            cmd.append("--all")
+        if parallel:
+            cmd.append("--parallel")
+
+    assert run_command(cmd).returncode == 0
+
+
+@pytest.mark.serial
+@pytest.mark.parametrize(
+    ("scenario_to_test", "driver_name", "scenario_name", "platform_name"),
+    [
+        ("driver/delegated", "delegated", "default", "instance"),
+    ],
+    indirect=["scenario_to_test", "driver_name", "scenario_name", "platform_name"],
+)
+def test_command_test_with_platform_name(
+    scenario_to_test, with_scenario, scenario_name, driver_name, platform_name
+):
+    run_test_with_platform_name(driver_name, platform_name, scenario_name)
+
+
+@pytest.mark.serial
+@pytest.mark.parametrize(
+    ("scenario_to_test", "driver_name", "scenario_name"),
+    [
+        (
+            "driver/delegated_invalid_role_name_with_role_name_check_equals_to_1",
+            "delegated",
+            "default",
+        ),
+    ],
+    indirect=["scenario_to_test", "driver_name", "scenario_name"],
+)
+def test_command_test_with_role_name_check_equals_to_1(
+    scenario_to_test, with_scenario, scenario_name, driver_name
+):
+    run_test(driver_name, scenario_name)
+
+
 @pytest.mark.serial
 @pytest.mark.extensive
 @pytest.mark.parametrize(
@@ -304,3 +358,12 @@ def test_command_test(scenario_to_test, with_scenario, scenario_name, driver_nam
 )
 def test_command_verify(scenario_to_test, with_scenario, scenario_name):
     verify(scenario_name)
+
+
+def test_sample_collection():
+    assert (
+        run_command(
+            ["molecule", "test"], cwd="src/molecule/test/resources/sample-collection"
+        ).returncode
+        == 0
+    )
