@@ -33,6 +33,49 @@ def _instance(config_instance):
     return _instance
 
 
+@pytest.fixture
+def _provisioner_section_data():
+    return {"provisioner": {"name": "ansible", "env": {"FOO": "bar"}}}
+
+
+@pytest.fixture
+def _verifier_section_data():
+    return {"verifier": {"name": "ansible", "env": {"FOO": "bar"}}}
+
+
+@pytest.fixture
+def _provisioner_verifier_section_data():
+    return {
+        "provisioner": {"name": "ansible", "env": {"FOO": "bar"}},
+        "verifier": {"name": "ansible", "env": {"FOO": "baz"}},
+    }
+
+
+@pytest.fixture
+def _instance_for_verifier_env(config_instance):
+    _instance = ansible_playbook.AnsiblePlaybook("playbook", config_instance, True)
+    return _instance
+
+
+@pytest.mark.parametrize(
+    "config_instance", ["_provisioner_section_data"], indirect=True
+)
+def test_env_in_provision(_instance_for_verifier_env):
+    assert "bar" == _instance_for_verifier_env._env["FOO"]
+
+
+@pytest.mark.parametrize("config_instance", ["_verifier_section_data"], indirect=True)
+def test_env_in_verifier(_instance_for_verifier_env):
+    assert "bar" == _instance_for_verifier_env._env["FOO"]
+
+
+@pytest.mark.parametrize(
+    "config_instance", ["_provisioner_verifier_section_data"], indirect=True
+)
+def test_env_in_verify_override_provision(_instance_for_verifier_env):
+    assert "baz" == _instance_for_verifier_env._env["FOO"]
+
+
 @pytest.fixture
 def _inventory_directory(_instance):
     return _instance._config.provisioner.inventory_directory
