@@ -149,9 +149,13 @@ def test_verifier_property_is_ansible(config_instance):
     assert isinstance(config_instance.verifier, AnsibleVerifier)
 
 
-def test_get_driver_name_from_state_file(config_instance):
+def test_get_driver_name_from_state_file(config_instance, mocker):
     config_instance.state.change_state("driver", "state-driver")
 
+    with pytest.raises(SystemExit):
+        config_instance._get_driver_name()
+
+    mocker.patch("molecule.api.drivers", return_value=["state-driver"])
     assert "state-driver" == config_instance._get_driver_name()
 
 
@@ -214,14 +218,14 @@ def test_reget_config(config_instance):
 
 def test_interpolate(patched_logger_critical, config_instance):
     string = "foo: $HOME"
-    x = "foo: {}".format(os.environ["HOME"])
+    x = f"foo: {os.environ['HOME']}"
 
     assert x == config_instance._interpolate(string, os.environ, None)
 
 
 def test_interpolate_curly(patched_logger_critical, config_instance):
     string = "foo: ${HOME}"
-    x = "foo: {}".format(os.environ["HOME"])
+    x = f"foo: {os.environ['HOME']}"
 
     assert x == config_instance._interpolate(string, os.environ, None)
 
@@ -242,14 +246,14 @@ def test_interpolate_default_colon(patched_logger_critical, config_instance):
 
 def test_interpolate_default_variable(patched_logger_critical, config_instance):
     string = "foo: ${NONE:-$HOME}"
-    x = "foo: {}".format(os.environ["HOME"])
+    x = f"foo: {os.environ['HOME']}"
 
     assert x == config_instance._interpolate(string, os.environ, None)
 
 
 def test_interpolate_curly_default_variable(patched_logger_critical, config_instance):
     string = "foo: ${NONE-$HOME}"
-    x = "foo: {}".format(os.environ["HOME"])
+    x = f"foo: {os.environ['HOME']}"
 
     assert x == config_instance._interpolate(string, os.environ, None)
 
@@ -265,10 +269,10 @@ def test_interpolate_raises_on_failed_interpolation(
     assert 1 == e.value.code
 
     msg = (
-        "parsing config file '{}'.\n\n"
+        f"parsing config file '{config_instance.molecule_file}'.\n\n"
         "Invalid placeholder in string: line 1, col 1\n"
         "$6$8I5Cfmpr$kGZB"
-    ).format(config_instance.molecule_file)
+    )
     patched_logger_critical.assert_called_once_with(msg)
 
 
